@@ -88,15 +88,14 @@ def lineplot(
     else:
         detail_kwarg = {"detail": detail}
 
-    y_kwarg = {}
-
+    y_scale_kwarg = {"zero": False}
     if log_y:
-        y_kwarg["base"] = 10
-
+        y_scale_kwarg["base"] = 10
     if limits is not None:
-        y_kwarg["scale"] = alt.Scale(zero=False, domain=limits)
-    else:
-        y_kwarg["scale"] = alt.Scale(zero=False)
+        y_scale_kwarg["domain"] = limits
+
+    y_kwarg = {}
+    y_kwarg["scale"] = alt.Scale(**y_kwarg_scale)
 
     if y_axis is not None:
         y_kwarg["axis"] = y_axis
